@@ -34,9 +34,7 @@ gls <-
     Call <- match.call()
     ## control parameters
     controlvals <- glsControl()
-    if (!missing(control)) {
-        controlvals[names(control)] <- control
-    }
+    if (!missing(control)) controlvals[names(control)] <- control
 
     ##
     ## checking arguments
@@ -288,20 +286,12 @@ glsApVar <-
         dims <- conLin$dims
         N <- dims$N - dims$REML * dims$p
         conLin[["logLik"]] <- 0               # making sure
-        Pars <- c(glsCoef, lSigma=log(sigma))
+        Pars <- if(fixedSigma) glsCoef else c(glsCoef, lSigma = log(sigma))
         val <- fdHess(Pars, glsApVar.fullGlsLogLik, glsSt, conLin, dims, N,
                       .relStep = .relStep, minAbsPar = minAbsPar)[["Hessian"]]
         if (all(eigen(val, only.values=TRUE)$values < 0)) {
             ## negative definite - OK
             val <- solve(-val)
-            ## return val with original dimensions to prevent crashing in intervals
-            ## 17-11-2015; Fixed sigma patch; SH Heisterkamp; Quantitative Solutions
-            if (fixedSigma && !is.null(dim(val))) {
-            	Pars <- c(glsCoef, lSigma=log(sigma))
-            	npars <- length(Pars)
-            	val <- rbind(cbind(val, rep(0,npars-1)),
-                             rep(0,npars))
-            }
             nP <- names(Pars)
             dimnames(val) <- list(nP, nP)
             attr(val, "Pars") <- Pars
@@ -426,22 +416,19 @@ ACF.gls <-
 
 anova.gls <-
     function(object, ..., test = TRUE, type = c("sequential", "marginal"),
-             adjustSigma = TRUE, Terms, L, verbose = FALSE)
+             adjustSigma = NA, Terms, L, verbose = FALSE)
 {
-	## 17-11-2015; Fixed sigma patch; SH Heisterkamp; Quantitative Solutions
     fixSig <- attr(object$modelStruct, "fixedSigma")
-	fixSig <- !is.null(fixSig) && fixSig
+    fixSig <- !is.null(fixSig) && fixSig
     Lmiss <- missing(L)
     ## returns the likelihood ratio statistics, the AIC, and the BIC
     dots <- list(...)
-    if ((rt <- length(dots) + 1L) == 1L) {
-        if (!inherits(object,"gls")) {
+    if ((rt <- length(dots) + 1L) == 1L) {    ## just one object
+        if (!inherits(object,"gls"))
             stop("object must inherit from class \"gls\"")
-        }
-        if (inherits(object, "gnls") && missing(adjustSigma)) {
-            ## REML correction already applied to gnls objects
-            adjustSigma <- FALSE
-        }
+	if(is.na(adjustSigma))
+	    ## REML correction already applied to gnls objects
+	    adjustSigma <- inherits(object, "gnls")
         dims <- object$dims
         N <- dims$N
         p <- dims$p
@@ -450,7 +437,7 @@ anova.gls <-
         vBeta <- attr(assign, "varBetaFact")
 	if (!REML && adjustSigma)
 	    ## using REML-like estimate of sigma under ML
-	    vBeta <- sqrt(N/(N - p)) * vBeta
+	    vBeta <- sqrt((N - p)/N) * vBeta
         c0 <- solve(t(vBeta), coef(object))
         nTerms <- length(assign)
         dDF <- N - p
@@ -462,20 +449,20 @@ anova.gls <-
             nDF <- integer(nTerms)
             for(i in 1:nTerms) {
                 nDF[i] <- length(assign[[i]])
-                if (type == "sequential") {       # type I SS
-                    c0i <- c0[assign[[i]]]
-                } else {
-                    c0i <- c(qr.qty(qr(vBeta[, assign[[i]], drop = FALSE]), c0))[1:nDF[i]]
-                }
+		c0i <-
+		    if (type == "sequential") # type I SS
+			c0[assign[[i]]]
+		    else ## "marginal"
+			qr.qty(qr(vBeta[, assign[[i]], drop = FALSE]), c0)[1:nDF[i]]
                 Fval[i] <- sum(c0i^2)/nDF[i]
-                Pval[i] <- 1 - pf(Fval[i], nDF[i], dDF)
+                Pval[i] <- pf(Fval[i], nDF[i], dDF, lower.tail=FALSE)
             }
             ##
             ## fixed effects F-values, df, and p-values
             ##
-            aod <- data.frame(nDF, Fval, Pval)
-            dimnames(aod) <-
-                list(names(assign),c("numDF", "F-value", "p-value"))
+	    aod <- data.frame(numDF = nDF, "F-value" = Fval, "p-value" = Pval,
+			check.names=FALSE)
+            rownames(aod) <- names(assign)
         } else {
             if (Lmiss) {                 # terms is given
                 if (is.numeric(Terms) && all(Terms == as.integer(Terms))) {
@@ -532,15 +519,15 @@ anova.gls <-
                 rownames(L) <- if(is.null(dmsL1)) 1:nrowL else dmsL1[noZeroRowL]
                 lab <- paste(lab, "F-test for linear combination(s)\n")
             }
-            nDF <- sum(svd(L)$d > 0)
+            nDF <- sum(svd.d(L) > 0)
             c0 <- c(qr.qty(qr(vBeta %*% t(L)), c0))[1:nDF]
             Fval <- sum(c0^2)/nDF
-            Pval <- 1 - pf(Fval, nDF, dDF)
-            aod <- data.frame(nDF, Fval, Pval)
-            names(aod) <- c("numDF", "F-value", "p-value")
+            Pval <- pf(Fval, nDF, dDF, lower.tail=FALSE)
+            aod <- data.frame(numDF = nDF, "F-value" = Fval, "p-value" = Pval,
+                              check.names=FALSE)
             if (!Lmiss) {
-                if (nrow(L) > 1) attr(aod, "L") <- L[, noZeroColL, drop = FALSE]
-                else attr(aod, "L") <- L[, noZeroColL]
+                attr(aod, "L") <-
+                    if(nrow(L) > 1) L[, noZeroColL, drop = FALSE] else L[, noZeroColL]
             }
         }
         attr(aod, "label") <- lab
@@ -787,17 +774,18 @@ intervals.gls <-
                       dims$N - dims$REML * dims$p
                   }
             ## 17-11-2015; Fixed sigma patch; SH Heisterkamp; Quantitative Solutions
-            if(!fixSig){
+            if(!fixSig) {
                 est <- object$sigma * sqrt(Nr)
                 val[["sigma"]] <-
-                    structure(c(est/sqrt(qchisq((1+level)/2, Nr)), object$sigma,
-                                est/sqrt(qchisq((1-level)/2, Nr))),
-                              names = c("lower", "est.", "upper"))
-                attr(val[["sigma"]], "label") <- "Residual standard error:"
+                    structure(c(lower = est/sqrt(qchisq((1+level)/2, Nr)),
+                                "est."= object$sigma,
+                                upper = est/sqrt(qchisq((1-level)/2, Nr))),
+                              label = "Residual standard error:")
             } else {
                 est <- 1
-                val[["sigma"]] <- structure(c(object$sigma,object$sigma,object$sigma), names = c("lower", "est.", "upper"))
-                attr(val[["sigma"]], "label") <- "Fixed Residual standard error:"
+		val[["sigma"]] <- structure(setNames(rep(object$sigma, 3),
+                                                     c("lower", "est.", "upper")),
+                                            label = "Fixed Residual standard error:")
             }
         } else {
             if (is.character(aV)) {
@@ -808,12 +796,13 @@ intervals.gls <-
             est <- attr(aV, "Pars")
             nP <- length(est)
             glsSt <- object[["modelStruct"]]
-            if (!all(whichKeep <- apply(attr(glsSt, "pmap"), 2, any))) {
+            pmap <- attr(glsSt, "pmap")
+            if (!all(whichKeep <- apply(pmap, 2, any))) {
                 ## need to deleted components with fixed coefficients
                 aux <- glsSt[whichKeep]
                 class(aux) <- class(glsSt)
                 attr(aux, "settings") <- attr(glsSt, "settings")
-                attr(aux, "pmap") <- attr(glsSt, "pmap")[, whichKeep, drop = FALSE]
+                attr(aux, "pmap") <- pmap[, whichKeep, drop = FALSE]
                 glsSt <- aux
             }
             cSt <- glsSt[["corStruct"]]
@@ -822,29 +811,28 @@ intervals.gls <-
                 class(cSt) <- c("corNatural", "corStruct")
                 glsSt[["corStruct"]] <- cSt
             }
-            pmap <- attr(glsSt, "pmap")
             namG <- names(glsSt)
             auxVal <- vector("list", length(namG) + 1L)
             names(auxVal) <- c(namG, "sigma")
             aux <-
                 array(c(est - len, est, est + len),
                       c(nP, 3), list(NULL, c("lower", "est.", "upper")))
-            auxVal[["sigma"]] <-
-                structure(if(!fixSig)
-                              exp(aux[nP, ])
-                          else
-                              c(object$sigma, object$sigma, object$sigma),
-                          label = "Residual standard error:")
-            aux <- aux[-nP,, drop = FALSE]
-            rownames(aux) <- ## namP <-
-                names(coef(glsSt, FALSE))
+	    auxVal[["sigma"]] <-
+		structure(if(!fixSig) { # last param. = log(sigma)
+			      s <- exp(aux[nP, ])
+			      aux <- aux[-nP,, drop = FALSE]
+			      s
+			  } else
+			      c(object$sigma, object$sigma, object$sigma),
+			  label = "Residual standard error:")
+            rownames(aux) <- names(coef(glsSt, FALSE))
             for(i in 1:3) {
                 coef(glsSt) <- aux[,i]
                 aux[,i] <- coef(glsSt, unconstrained = FALSE)
             }
             for(i in namG) {
                 au.i <- aux[pmap[,i], , drop = FALSE]
-                dimnames(au.i)[[1]] <- substring(dimnames(au.i)[[1]], nchar(i, "c") + 2)
+                dimnames(au.i)[[1]] <- substring(dimnames(au.i)[[1]], nchar(i, "c") + 2L)
                 attr(au.i, "label") <-
                     switch(i,
                            corStruct = "Correlation structure:",
@@ -872,11 +860,11 @@ logLik.gls <-
     val <- object[["logLik"]]
     if (REML && estM == "ML") { # have to correct logLik
         val <- val + (p * (log(2 * pi) + 1) + Np * log(1 - p/N) +
-                      sum(log(abs(svd(object$varBeta)$d)))) / 2
+                      sum(log(abs(svd.d(object$varBeta))))) / 2
     }
     else if (!REML && (estM == "REML")) { # have to correct logLik
         val <- val - (p * (log(2*pi) + 1) + N * log(1 - p/N) +
-                      sum(log(abs(svd(object$varBeta)$d)))) / 2
+                      sum(log(abs(svd.d(object$varBeta))))) / 2
     }
     structure(val,
               nall = N,
@@ -1005,10 +993,8 @@ print.summary.gls <-
     function(x, verbose = FALSE, digits = .Options$digits, ...)
 {
     dd <- x$dims
-    ## 17-11-2015; Fixed sigma patch; SH Heisterkamp; Quantitative Solutions
-	fixSig <- attr(x[["modelStruct"]], "fixedSigma")
-	fixSig <- !is.null(fixSig) && fixSig
-
+    fixSig <- attr(x[["modelStruct"]], "fixedSigma")
+    fixSig <- !is.null(fixSig) && fixSig
     verbose <- verbose || attr(x, "verbose")
     mCall <- x$call
     if (inherits(x, "gnls")) {
@@ -1373,7 +1359,7 @@ glsControl <-
     function(maxIter = 50L, msMaxIter = 200L, tolerance = 1e-6, msTol = 1e-7,
              msVerbose = FALSE, singular.ok = FALSE,
              returnObject = FALSE,
-             apVar = TRUE, .relStep = (.Machine$double.eps)^(1/3),
+             apVar = TRUE, .relStep = .Machine$double.eps^(1/3),
 	     opt = c("nlminb", "optim"),  optimMethod = "BFGS",
              minAbsParApVar = 0.05, natural = TRUE, sigma = NULL)
 {
@@ -1381,9 +1367,9 @@ glsControl <-
     if(is.null(sigma))
 	sigma <- 0
     else {
-	if(!is.finite(sigma) || length(sigma) != 1 || sigma <= 0)
+	if(!is.finite(sigma) || length(sigma) != 1 || sigma < 0)
 	    stop("Within-group std. dev. must be a positive numeric value")
-	if(missing(apVar)) apVar <- FALSE # not yet implemented
+	## if(missing(apVar)) apVar <- FALSE # not yet implemented
     }
     list(maxIter = maxIter, msMaxIter = msMaxIter, tolerance = tolerance,
          msTol = msTol, msVerbose = msVerbose,
